@@ -545,7 +545,8 @@ an array as a variable:
 
 Currently, when the arguments do not fit the signature because of a L<Moose>
 validation error, the response body will be set to C<Bad Request> and the
-status to C<400>.
+status to C<400>. This only applies when debug mode is off. If it is turned on,
+the error message will be prefixed with C<BAD REQUEST: >.
 
 =head2 Actions and Method Modifiers
 
